/*
**  CXSC is a C++ library for eXtended Scientific Computing 
**
**  Copyright (C) 1990-2000 Institut fuer Angewandte Mathematik,
**                          Universitaet Karlsruhe, Germany
**            (C) 2000-2006 Wiss. Rechnen/Softwaretechnologie
**                          Universitaet Wuppertal, Germany
**
**  MPI communication package for C-XSC Taylor arithmetic data types
**
**  Copyright (C) 2004-2007 Markus Grimmer
**
**  markus.grimmer@math.uni-wuppertal.de
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Library General Public
**  License as published by the Free Software Foundation; either
**  version 2 of the License, or (at your option) any later version.
**
**  This library is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
**  Library General Public License for more details.
**
**  You should have received a copy of the GNU Library General Public
**  License along with this library; if not, write to the Free
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/**
 * @file taylor_mpicomm.hpp
 * 
 * MPI communication package for C-XSC Taylor arithmetic data types: 
 * Header.
 *
 * Copyright (C) 2004-2007 Markus Grimmer
 *
 * Incorporated Routines:
 *
 * <ul>
 * <li> MPI_Pack, MPI_Unpack </li>
 * </ul>
 *
 * Incorporated Types:
 *
 * <ul>
 * <li> itaylor, dim2taylor, dim2taylor_vector </li>
 * </ul>
 */

#ifndef _TAYLOR_MPICOMM_INCLUDE
#define _TAYLOR_MPICOMM_INCLUDE

#include <mpi.h>

#include "itaylor.hpp"
#include "dim2taylor.hpp"

using namespace cxsc;
using namespace taylor;

/**
 * @name Pack and Unpack for 1D/2D C-XSC Taylor arithmetic types
 */
//@{
int MPI_Pack (itaylor&, void *, int, int *,  MPI_Comm);
int MPI_Unpack (void*, int, int *, itaylor&, MPI_Comm);
int MPI_Pack (dim2taylor&, void *, int, int *,  MPI_Comm);
int MPI_Unpack (void*, int, int *, dim2taylor&, MPI_Comm);
int MPI_Pack (dim2taylor_vector&, void *, int, int *,  MPI_Comm);
int MPI_Unpack (void*, int, int *, dim2taylor_vector&, MPI_Comm);
//@}

// Communication routines not separately implemented:
// See template versions in module cxsc_mpicomm_templ

#endif
